@@ -1,12 +1,12 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001002';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001003';
 #pod =encoding UTF-8
 #pod  
 #pod =head1 SYNOPSIS
 #pod  
-#pod Put following into your C<dist.ini>:
+#pod Put following into your C<My-Module/dist.ini>:
 #pod
 #pod 	[@Author::MAXHQ]
 #pod 	GatherDir.exclude_match = ^[^\/\.]+\.txt$
@@ -19,14 +19,15 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001002';
 #pod 	# Files included
 #pod 	#
 #pod 	[GatherDir]
-#pod 	prune_directory=^extlib$
+#pod 	prune_directory = ^extlib$
+#pod 	include_dotfiles = 1
 #pod 	
 #pod 	[PruneCruft]
 #pod 	[ExecDir]
 #pod 	dir = bin
 #pod 	
 #pod 	[ShareDir]
-#pod 	dir = share
+#pod 	dir = share/dist/My-Module
 #pod 	
 #pod 	#
 #pod 	# Conversion and replacements
@@ -58,7 +59,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001002';
 #pod 	[PrereqsClean]
 #pod
 #pod 	[Prereqs / MAXHQ]
-#pod 	-phase = build
+#pod 	-phase = devlop
 #pod 	-relationship = requires
 #pod 	Pod::Elemental::Transformer::List = 0
 #pod 	Pod::Coverage::TrustPod = 0
@@ -144,15 +145,14 @@ sub configure {
 		['GatherDir' => {                 # skip files on top level
 			exclude_match => \@exclude_matches,
 			prune_directory => ['^extlib$'],
+			include_dotfiles => 1, # needed e.g. for ".devdir"
 		}],
 		'PruneCruft',                     # prune stuff you probably don't want
-		
+
 		['ExecDir' => {                   # install contents of bin/ as executable
 			dir => 'bin',
 		}],		
-		['ShareDir' => {                  # include all files in /share
-			dir => 'share',
-		}],
+		'ShareDir::ProjectDistDir',       # include all files in /share/dist/My-Dist
 		
 		#
 		# Conversion and replacements
@@ -238,6 +238,47 @@ sub configure {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
+{
+	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
+	# ABSTRACT: install a directory's contents as "ShareDir" content
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '1.001003';
+use Moose;
+	use namespace::autoclean;
+
+	with 'Dist::Zilla::Role::ShareDir';
+
+ 	use File::Spec;
+ 
+	has dir => (
+		is	 => 'ro',
+		isa	=> 'Str',
+		lazy_build => 1,
+	);
+	
+	sub _build_dir {
+		my ($self) = @_;
+		return File::Spec->catfile('share', 'dist', $self->zilla->name),
+	}
+	 
+	sub find_files {
+		my ($self) = @_;
+		my $dir = $self->dir;
+		return [
+			grep { index($_->name, "$dir/") == 0 }
+				@{ $self->zilla->files }
+		];
+	}
+	 
+	sub share_dir_map {
+		my ($self) = @_;
+		my $files = $self->find_files;
+		return unless @$files;
+		return { dist => $self->dir };
+	}
+	 
+	__PACKAGE__->meta->make_immutable;
+}
+
 __END__
 
 =pod
@@ -248,11 +289,11 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.001002
+version 1.001003
 
 =head1 SYNOPSIS
 
-Put following into your C<dist.ini>:
+Put following into your C<My-Module/dist.ini>:
 
 	[@Author::MAXHQ]
 	GatherDir.exclude_match = ^[^\/\.]+\.txt$
@@ -265,14 +306,15 @@ Currently this plugin bundle is equivalent to:
 	# Files included
 	#
 	[GatherDir]
-	prune_directory=^extlib$
+	prune_directory = ^extlib$
+	include_dotfiles = 1
 	
 	[PruneCruft]
 	[ExecDir]
 	dir = bin
 	
 	[ShareDir]
-	dir = share
+	dir = share/dist/My-Module
 	
 	#
 	# Conversion and replacements
@@ -304,7 +346,7 @@ Currently this plugin bundle is equivalent to:
 	[PrereqsClean]
 
 	[Prereqs / MAXHQ]
-	-phase = build
+	-phase = devlop
 	-relationship = requires
 	Pod::Elemental::Transformer::List = 0
 	Pod::Coverage::TrustPod = 0
